@@ -6,6 +6,7 @@
 .. autoclass:: BaseModel
     :members:
 """
+from functools import wraps
 from sqlalchemy.orm.properties import RelationshipProperty
 from sqlalchemy.orm.collections import InstrumentedList
 
@@ -32,10 +33,56 @@ class ClassProperty(property):
         return self.fget.__get__(None, owner)()
 
 
+def query_operation(decorated_method=None, operation_name=None):
+    """
+    query_operation process a search on a query with criterion and operators.
+    Then, the operation_name operation is called on the query. If operation_name is not set
+    the operation_name is taken from the decorated method
+
+    .. code-block:: python
+
+        @query_operation
+        def count(cls, *operators, **criterions):
+            # This method will call the cls.search(*operators, **criterions)
+            # Then , it will call count operation on the result of previous search
+            # I.E. : the generated code will be "return cls.search(*operators, **criterions).count()"
+
+        @query_operation(operation_name='one')
+        def get(cls, *operators, **criterions):
+            # It will process the same thing above, except the function compute on the query will be 'one'
+            # I.E. : return cls.search(*operators, **criterions).one()
+ 
+    .. warning:
+
+        This decorataror defines the decorated_method as a classmethod.
+
+    """
+
+    if  decorated_method and operation_name is None:
+        operation_name = decorated_method.__name__
+
+    def _wrapper(decorated_method):
+
+        @classmethod
+        @wraps(decorated_method)
+        def _decorator(querying_class, *operators, **criterions):
+
+            query = querying_class.search(*operators, **criterions)
+            method = query.__getattribute__(operation_name)
+            return method()
+
+        return _decorator
+
+    if decorated_method is not None:
+        return _wrapper(decorated_method)
+    else:
+        return _wrapper
+
+
 class BaseModel(object):
     """
     Base Model Class.
-    Provide syntatix sugar for getting object from database.
+    Provide syntactic sugar for getting object from database.
     """
 
     sessionmaker = None
@@ -49,7 +96,7 @@ class BaseModel(object):
         This registered function mustn't have any parameters.
         For a globale session, just put the session as parameter.
         If a session maker is already registered, an exception is raised to avoid conflict.
-        But, if you are sur about what your are doing, you can set `force` parameter to True.
+        But, if you are sure about what your are doing, you can set `force` parameter to True.
         It's not advice.
         """
         if cls.sessionmaker is None or force:
@@ -73,7 +120,7 @@ class BaseModel(object):
     def search(cls, *operator, **criterion):
         """
         Object search with criterions given in arguments.
-        Return a :class:`sqlachemy.orm.query.Query` object.
+        Returns a :class:`sqlachemy.orm.query.Query` object.
 
         Filters can be chained.
         """
@@ -93,38 +140,42 @@ class BaseModel(object):
         return query.filter(*clauses)
 
 
-    @classmethod
+    @query_operation(operation_name='one')
     def get(cls, *operators, **criterions):
         """
-        Return a object with criterions given in parameters.
+        Returns an object with criterions given in parameters.
         """
-        query = cls.search(*operators, **criterions)
-        return query.one()
 
-
-    @classmethod
+    @query_operation
     def all(cls):
         """
-        Return all objects from the same class contains in database.
+        Returns all objects from the same class contained in database.
         """
-        return cls.search().all()
 
-
-    @classmethod
+    @query_operation
     def filter(cls, *operators, **criterions):
         """
-        Return a list of objects from a class matching criterions given in parameters.
+        Returns a list of objects from a class matching criterions given in parameters.
+        """
+
+    @query_operation
+    def count(cls, *operators, **criterions):
+        """
+        Returns the number of objects matched by criterions
+
+        .. code-block:: python
+
+           >>> Treatment.count(status=u'OK')
+           8
         """
-        query = cls.search(*operators, **criterions)
-        return query.all()
 
 
     @classmethod
     def load(cls, dictionary, hard=False):
         """
-        Return a object from class with attributes got in dictionary's parameters.
+        Returns an object from class with attributes got in dictionary's parameters.
 
-        If all the primary key are found in the dictionary, the object is
+        If all the primary keys are found in the dictionary, the object is
         loaded from database. Otherwise, values are set in the loading object.
 
         .. code-block:: python
@@ -139,7 +190,7 @@ class BaseModel(object):
             >>> Treatment.get(id=1).name
             'Awesome Treatment'
 
-        If `hard` parameter is True, an axception is raised if a value isn't found
+        If `hard` parameter is True, an exception is raised if a value isn't found
         in parameter's dictionary.
         """
 
@@ -204,13 +255,13 @@ class BaseModel(object):
 
     def dump(self, excludes=[], depth=2):
         """
-        Return object as dictionary with dependencies.
+        Returns object as dictionary with dependencies.
 
         `Depth` limits the recursion.
 
         IE : With depth set as 1, objects in relations aren't search.
 
-        `excludes` use to excludes unwanted attributes.
+        `excludes` use to exclude unwanted attributes.
 
         .. code-block:: python
 
